pub struct PreparedTransaction { /* private fields */ }Expand description
A durably staged transaction holding the exclusive worktree lock.
Implementations
Sourceimpl PreparedTransaction
impl PreparedTransaction
Sourcepub fn commit(self) -> Result<ApplyReport, WorktreeError>
pub fn commit(self) -> Result<ApplyReport, WorktreeError>
Revalidates and commits every staged target in deterministic path order.
Sourcepub fn abort(self) -> Result<AbortReport, WorktreeError>
pub fn abort(self) -> Result<AbortReport, WorktreeError>
Discards a prepared transaction without changing a target.
Sourceimpl PreparedTransaction
impl PreparedTransaction
pub fn transaction_id(&self) -> &str
pub const fn preview(&self) -> &DryRunReport