pub struct WorktreeOptions {
pub limits: WorktreeLimits,
pub parallelism: usize,
}Expand description
Runtime policy for opening and preparing a worktree transaction.
Fields
limits: WorktreeLimitsparallelism: usizeZero selects bounded automatic parallelism.
Implementations
Sourceimpl WorktreeOptions
impl WorktreeOptions
pub const fn with_limits(self, limits: WorktreeLimits) -> Self
Sourcepub const fn with_parallelism(self, parallelism: usize) -> Self
pub const fn with_parallelism(self, parallelism: usize) -> Self
Sets preparation workers. Zero restores bounded automatic selection.
pub fn validate(&self) -> Result<(), WorktreeError>
Sourcepub fn worker_count(&self, file_count: usize) -> usize
pub fn worker_count(&self, file_count: usize) -> usize
Resolves the bounded worker count for a known number of files.